@@ -13,7 +13,8 @@ from input_algorithms.meta import Meta
 from option_merge.collector import Collector
 from option_merge import MergedOptions
 
-import yaml
+from ruamel.yaml import YAML
+import ruamel.yaml
 import os
 
 class Collector(Collector):
@@ -69,8 +70,8 @@ class Collector(Collector):
     def read_file(self, location):
         """Read in a yaml file and return as a python object"""
         try:
-            return yaml.load(open(location))
-        except (yaml.parser.ParserError, yaml.scanner.ScannerError) as error:
+            return YAML(typ='safe').load(open(location))
+        except (ruamel.yaml.parser.ParserError, ruamel.yaml.scanner.ScannerError) as error:
             raise self.BadFileErrorKls("Failed to read yaml"
                 , location=location
                 , error_type=error.__class__.__name__
